.. _astroML_classification:

Supervised Learning: Classification
===================================
More information will be here soon - check for updates!

Some examples of classification problems can be found in
:ref:`book_fig_chapter9`
